#ifndef EFL_GENERATED_EFL_FILE_HH
#define EFL_GENERATED_EFL_FILE_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "efl_file.eo.h"
}

#include <string>

namespace efl {

struct file
      : efl::eo::base
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit file(Eo* eo)
      : efl::eo::base(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit file(std::nullptr_t)
      : efl::eo::base(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   file(file const& other)
      : efl::eo::base(eo_ref(other._eo_ptr()))
   {}

   ~file() {}

   /// @brief Retrieve the source file from where an image object is to fetch the
   /// real image data (it may be an Eet file, besides pure image ones).
   ///
   /// You must @b not modify the strings on the returned pointers.
   ///
   /// @note Use @c NULL pointers on the file components you're not
   /// interested in: they'll be ignored by the function.
   ///
   /// @param file The image file path.
   /// @param key The image key in @p file (if its an Eet one), or @c
   /// NULL, otherwise.
   ///
   void file_get(const char ** file_, const char ** key_) const
   {
      eo_do(_eo_ptr(), ::efl_file_get(file_, key_));
   }

   /// @brief Set the source file from where an image object must fetch the real
   /// image data (it may be an Eet file, besides pure image ones).
   ///
   /// If the file supports multiple data stored in it (as Eet files do),
   /// you can specify the key to be used as the index of the image in
   /// this file.
   ///
   /// Example:
   /// @code
   /// img = evas_object_image_add(canvas);
   /// evas_object_image_file_set(img, "/path/to/img", NULL);
   /// err = evas_object_image_load_error_get(img);
   /// if (err != EVAS_LOAD_ERROR_NONE)
   /// {
   /// fprintf(stderr, "could not load image '%s'. error string is \"%s\"\n",
   /// valid_path, evas_load_error_str(err));
   /// }
   /// else
   /// {
   /// evas_object_image_fill_set(img, 0, 0, w, h);
   /// evas_object_resize(img, w, h);
   /// evas_object_show(img);
   /// }
   /// @endcode
   ///
   /// @param file The image file path.
   /// @param key The image key in @p file (if its an Eet one), or @c
   /// NULL, otherwise.
   ///
   bool file_set(std::string file_, std::string key_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(key_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Save the given image object's contents to an (image) file.
   ///
   /// The extension suffix on @p file will determine which <b>saver
   /// module</b> Evas is to use when saving, thus the final file's
   /// format. If the file supports multiple data stored in it (Eet ones),
   /// you can specify the key to be used as the index of the image in it.
   ///
   /// You can specify some flags when saving the image.  Currently
   /// acceptable flags are @c quality and @c compress. Eg.: @c
   /// "quality=100 compress=9"
   ///
   /// @param file The filename to be used to save the image (extension
   /// obligatory).
   /// @param key The image key in the file (if an Eet one), or @c NULL,
   /// otherwise.
   /// @param flags String containing the flags to be used (@c NULL for
   /// none).
   ///
   bool save(std::string file_, std::string key_, std::string flags_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_file_save(efl::eolian::to_c(file_), efl::eolian::to_c(key_), efl::eolian::to_c(flags_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Eject the represented object.
   ///
   /// Get rid of and clean the pointed resource.
   ///
   void eject() const
   {
      eo_do(_eo_ptr(), ::efl_file_eject());
   }

   static Eo_Class const* _eo_class()
   {
      return(EFL_FILE_INTERFACE);
   }

private:
};
} 

template <typename T>
void efl_file_file_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** file_, const char ** key_)
{
   static_cast<T*>(self->this_)->file_get(file_, key_);
}

template <typename T>
bool efl_file_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, const char * key_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(key_, std::tuple<std::false_type>()));
}

template <typename T>
bool efl_file_save_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, const char * key_, const char * flags_)
{
   return static_cast<T*>(self->this_)->save(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(key_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(flags_, std::tuple<std::false_type>()));
}

template <typename T>
void efl_file_eject_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->eject();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< efl::file >
{
   template <typename T>
   struct type
   {
      virtual void file_get(const char ** file_, const char ** key_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_file_get(file_, key_));
      }

      virtual bool file_set(std::string file_, std::string key_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(key_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool save(std::string file_, std::string key_, std::string flags_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_file_save(efl::eolian::to_c(file_), efl::eolian::to_c(key_), efl::eolian::to_c(flags_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void eject()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_file_eject());
      }

   };
};


template<>
struct operation_description_class_size< efl::file >
{
   static const int value = 4;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<efl::file>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::efl_file_file_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::efl_file_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::efl_file_file_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::efl_file_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::efl_file_save_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::efl_file_save);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::efl_file_eject_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::efl_file_eject);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< efl::file >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<efl::file, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< efl::file>
{
   template <typename U>
   struct type
   {
      operator efl::file() const
      {
         return efl::file(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void file_get(const char ** file_, const char ** key_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_file_get(file_, key_));
      }

      bool file_set(std::string file_, std::string key_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(key_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool save(std::string file_, std::string key_, std::string flags_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_file_save(efl::eolian::to_c(file_), efl::eolian::to_c(key_), efl::eolian::to_c(flags_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void eject()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_file_eject());
      }

   };
};

inline Eo_Class const* get_eo_class(tag<efl::file>)
{
   return (EFL_FILE_INTERFACE);
}

} } }
#endif // EFL_GENERATED_EFL_FILE_HH

