#ifndef EFL_GENERATED_EFL_PLAYER_HH
#define EFL_GENERATED_EFL_PLAYER_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "efl_player.eo.h"
}


namespace efl {

struct player
      : efl::eo::base
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit player(Eo* eo)
      : efl::eo::base(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit player(std::nullptr_t)
      : efl::eo::base(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   player(player const& other)
      : efl::eo::base(eo_ref(other._eo_ptr()))
   {}

   ~player() {}

   /// @brief * @brief Get play/pause state of the media file.
   ///
   /// @param play true if playing, false otherwise.
   ///
   bool play_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_play_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief * @brief Set play/pause state of the media file.
   /// *
   /// * This functions sets the currently playing status of the video. Using this
   /// * function to play or pause the video doesn't alter it's current position.
   ///
   /// @param play true if playing, false otherwise.
   ///
   void play_set(bool play_) const
   {
      eo_do(_eo_ptr(), ::efl_player_play_set(efl::eolian::to_c(play_)));
   }

   /// @brief * @brief Get the position in the media file.
   /// *
   /// * @param obj The emotion object from which the position will be retrieved.
   /// * @return The position of the media file.
   /// *
   /// * The position is returned as the number of seconds since the beginning of the
   /// * media file.
   ///
   /// @param second The position (in seconds).
   ///
   double position_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_position_get());
      return _tmp_ret;
   }

   /// @brief * @brief Set the position in the media file.
   /// *
   /// * @param obj The emotion object whose position will be changed.
   /// * @param sec The position(in seconds) to which the media file will be set.
   /// *
   /// * This functions sets the current position of the media file to @p sec, this
   /// * only works on seekable streams. Setting the position doesn't change the
   /// * playing state of the media file.
   ///
   /// @param second The position (in seconds).
   ///
   void position_set(double second_) const
   {
      eo_do(_eo_ptr(), ::efl_player_position_set(second_));
   }

   /// @brief * @brief Get how much of the file has been played.
   /// *
   /// * This function gets the progress in playing the file, the return value is in
   /// * the [0, 1] range.
   ///
   /// @param progress The progress within the [0, 1] range.
   ///
   double progress_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_progress_get());
      return _tmp_ret;
   }

   /// @param speed The play speed in the [0, infinity) range.
   ///
   double play_speed_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_play_speed_get());
      return _tmp_ret;
   }

   /// @param speed The play speed in the [0, infinity) range.
   ///
   void play_speed_set(double speed_) const
   {
      eo_do(_eo_ptr(), ::efl_player_play_speed_set(speed_));
   }

   /// @param volume The volume level
   ///
   double audio_volume_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_audio_volume_get());
      return _tmp_ret;
   }

   /// @param volume The volume level
   ///
   void audio_volume_set(double volume_) const
   {
      eo_do(_eo_ptr(), ::efl_player_audio_volume_set(volume_));
   }

   /// @param mute The mute state. True or false.
   ///
   bool audio_mute_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_player_audio_mute_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param mute The mute state. True or false.
   ///
   void audio_mute_set(bool mute_) const
   {
      eo_do(_eo_ptr(), ::efl_player_audio_mute_set(efl::eolian::to_c(mute_)));
   }

   static Eo_Class const* _eo_class()
   {
      return(EFL_PLAYER_INTERFACE);
   }

private:
};
} 

template <typename T>
bool efl_player_play_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->play_get();
}

template <typename T>
void efl_player_play_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool play_)
{
   static_cast<T*>(self->this_)->play_set(efl::eolian::to_cxx<bool>(play_, std::tuple<std::false_type>()));
}

template <typename T>
double efl_player_position_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->position_get();
}

template <typename T>
void efl_player_position_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double second_)
{
   static_cast<T*>(self->this_)->position_set(second_);
}

template <typename T>
double efl_player_progress_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->progress_get();
}

template <typename T>
double efl_player_play_speed_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->play_speed_get();
}

template <typename T>
void efl_player_play_speed_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double speed_)
{
   static_cast<T*>(self->this_)->play_speed_set(speed_);
}

template <typename T>
double efl_player_audio_volume_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->audio_volume_get();
}

template <typename T>
void efl_player_audio_volume_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double volume_)
{
   static_cast<T*>(self->this_)->audio_volume_set(volume_);
}

template <typename T>
bool efl_player_audio_mute_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->audio_mute_get();
}

template <typename T>
void efl_player_audio_mute_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mute_)
{
   static_cast<T*>(self->this_)->audio_mute_set(efl::eolian::to_cxx<bool>(mute_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< efl::player >
{
   template <typename T>
   struct type
   {
      virtual bool play_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_play_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void play_set(bool play_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_player_play_set(efl::eolian::to_c(play_)));
      }

      virtual double position_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_position_get());
            return _tmp_ret;
      }

      virtual void position_set(double second_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_player_position_set(second_));
      }

      virtual double progress_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_progress_get());
            return _tmp_ret;
      }

      virtual double play_speed_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_play_speed_get());
            return _tmp_ret;
      }

      virtual void play_speed_set(double speed_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_player_play_speed_set(speed_));
      }

      virtual double audio_volume_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_audio_volume_get());
            return _tmp_ret;
      }

      virtual void audio_volume_set(double volume_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_player_audio_volume_set(volume_));
      }

      virtual bool audio_mute_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_player_audio_mute_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void audio_mute_set(bool mute_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_player_audio_mute_set(efl::eolian::to_c(mute_)));
      }

   };
};


template<>
struct operation_description_class_size< efl::player >
{
   static const int value = 11;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<efl::player>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::efl_player_play_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::efl_player_play_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::efl_player_play_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::efl_player_play_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::efl_player_position_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::efl_player_position_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::efl_player_position_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::efl_player_position_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::efl_player_progress_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::efl_player_progress_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::efl_player_play_speed_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::efl_player_play_speed_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::efl_player_play_speed_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::efl_player_play_speed_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::efl_player_audio_volume_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::efl_player_audio_volume_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::efl_player_audio_volume_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::efl_player_audio_volume_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::efl_player_audio_mute_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::efl_player_audio_mute_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::efl_player_audio_mute_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::efl_player_audio_mute_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< efl::player >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<efl::player, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< efl::player>
{
   template <typename U>
   struct type
   {
      operator efl::player() const
      {
         return efl::player(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool play_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_play_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void play_set(bool play_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_player_play_set(efl::eolian::to_c(play_)));
      }

      double position_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_position_get());
            return _tmp_ret;
      }

      void position_set(double second_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_player_position_set(second_));
      }

      double progress_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_progress_get());
            return _tmp_ret;
      }

      double play_speed_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_play_speed_get());
            return _tmp_ret;
      }

      void play_speed_set(double speed_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_player_play_speed_set(speed_));
      }

      double audio_volume_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_audio_volume_get());
            return _tmp_ret;
      }

      void audio_volume_set(double volume_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_player_audio_volume_set(volume_));
      }

      bool audio_mute_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_player_audio_mute_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void audio_mute_set(bool mute_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_player_audio_mute_set(efl::eolian::to_c(mute_)));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<efl::player>)
{
   return (EFL_PLAYER_INTERFACE);
}

} } }
#endif // EFL_GENERATED_EFL_PLAYER_HH

