#ifndef EFL_GENERATED_EFL_TEXT_PROPERTIES_HH
#define EFL_GENERATED_EFL_TEXT_PROPERTIES_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "efl_text_properties.eo.h"
}

#include <string>

namespace efl {

struct text_properties
      : efl::eo::base
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit text_properties(Eo* eo)
      : efl::eo::base(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit text_properties(std::nullptr_t)
      : efl::eo::base(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   text_properties(text_properties const& other)
      : efl::eo::base(eo_ref(other._eo_ptr()))
   {}

   ~text_properties() {}

   /// @brief Retrieve the font family and size in use on a given text object.
   ///
   /// This function allows the font name and size of a text object to be
   /// queried. Be aware that the font name string is still owned by Evas
   /// and should @b not have free() called on it by the caller of the
   /// function.
   ///
   /// @see evas_object_text_font_set()
   ///
   /// @param font The font family name or filename.
   /// @param size The font size, in points.
   ///
   void font_get(const char ** font_, Efl_Font_Size* size_) const
   {
      eo_do(_eo_ptr(), ::efl_text_properties_font_get(font_, size_));
   }

   /// @brief Set the font family or filename, and size on a given text object.
   ///
   /// This function allows the font name and size of a text object to be
   /// set. The @p font string has to follow fontconfig's convention on
   /// naming fonts, as it's the underlying library used to query system
   /// fonts by Evas (see the @c fc-list command's output, on your system,
   /// to get an idea). Alternatively, one can use a full path to a font file.
   ///
   /// @see evas_object_text_font_get()
   /// @see evas_object_text_font_source_set()
   ///
   /// @param font The font family name or filename.
   /// @param size The font size, in points.
   ///
   void font_set(std::string font_, Efl_Font_Size size_) const
   {
      eo_do(_eo_ptr(), ::efl_text_properties_font_set(efl::eolian::to_c(font_), size_));
   }

   /// @brief Get the font file's path which is being used on a given text
   /// object.
   ///
   /// @return The font file's path.
   ///
   /// @see evas_object_text_font_get() for more details
   ///
   /// @param font_source The font file's path.
   ///
   std::string font_source_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::efl_text_properties_font_source_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set the font (source) file to be used on a given text object.
   ///
   /// This function allows the font file to be explicitly set for a given
   /// text object, overriding system lookup, which will first occur in
   /// the given file's contents.
   ///
   /// @see evas_object_text_font_get()
   ///
   /// @param font_source The font file's path.
   ///
   void font_source_set(std::string font_source_) const
   {
      eo_do(_eo_ptr(), ::efl_text_properties_font_source_set(efl::eolian::to_c(font_source_)));
   }

   static Eo_Class const* _eo_class()
   {
      return(EFL_TEXT_PROPERTIES_INTERFACE);
   }

private:
};
} 

template <typename T>
void efl_text_properties_font_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** font_, Efl_Font_Size* size_)
{
   static_cast<T*>(self->this_)->font_get(font_, size_);
}

template <typename T>
void efl_text_properties_font_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_, Efl_Font_Size size_)
{
   static_cast<T*>(self->this_)->font_set(efl::eolian::to_cxx<std::string>(font_, std::tuple<std::false_type>()), size_);
}

template <typename T>
std::string efl_text_properties_font_source_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->font_source_get();
}

template <typename T>
void efl_text_properties_font_source_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_source_)
{
   static_cast<T*>(self->this_)->font_source_set(efl::eolian::to_cxx<std::string>(font_source_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< efl::text_properties >
{
   template <typename T>
   struct type
   {
      virtual void font_get(const char ** font_, Efl_Font_Size* size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_text_properties_font_get(font_, size_));
      }

      virtual void font_set(std::string font_, Efl_Font_Size size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_text_properties_font_set(efl::eolian::to_c(font_), size_));
      }

      virtual std::string font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::efl_text_properties_font_source_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void font_source_set(std::string font_source_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::efl_text_properties_font_source_set(efl::eolian::to_c(font_source_)));
      }

   };
};


template<>
struct operation_description_class_size< efl::text_properties >
{
   static const int value = 4;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<efl::text_properties>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::efl_text_properties_font_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::efl_text_properties_font_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::efl_text_properties_font_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::efl_text_properties_font_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::efl_text_properties_font_source_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::efl_text_properties_font_source_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::efl_text_properties_font_source_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::efl_text_properties_font_source_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< efl::text_properties >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<efl::text_properties, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< efl::text_properties>
{
   template <typename U>
   struct type
   {
      operator efl::text_properties() const
      {
         return efl::text_properties(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void font_get(const char ** font_, Efl_Font_Size* size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_text_properties_font_get(font_, size_));
      }

      void font_set(std::string font_, Efl_Font_Size size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_text_properties_font_set(efl::eolian::to_c(font_), size_));
      }

      std::string font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::efl_text_properties_font_source_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void font_source_set(std::string font_source_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::efl_text_properties_font_source_set(efl::eolian::to_c(font_source_)));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<efl::text_properties>)
{
   return (EFL_TEXT_PROPERTIES_INTERFACE);
}

} } }
#endif // EFL_GENERATED_EFL_TEXT_PROPERTIES_HH

