#ifndef EFL_GENERATED_EVAS_3D_CAMERA_HH
#define EFL_GENERATED_EVAS_3D_CAMERA_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_3d_camera.eo.h"
}

#include "evas_3d_object.eo.hh"
#include "evas_common_interface.eo.hh"

struct evas_3d_camera
      : evas_3d_object,
      efl::eo::detail::extension_inheritance<evas::common_interface>::template type< ::evas_3d_camera>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_3d_camera(Eo* eo)
      : evas_3d_object(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit evas_3d_camera(std::nullptr_t)
      : evas_3d_object(nullptr)
   {}

   /// @brief Call the object's constructor.
   /// Should not be used with #eo_do. Only use it with #eo_do_super.
   ///
   evas_3d_camera(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_3d_camera(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_3d_camera(evas_3d_camera const& other)
      : evas_3d_object(eo_ref(other._eo_ptr()))
   {}

   ~evas_3d_camera() {}

   /// @brief Pure virtual update_notify function..
   /// Update request for the object.
   ///
   void update_notify() const
   {
      eo_do(_eo_ptr(), ::evas_3d_object_update_notify());
   }

   /// @brief Pure virtual change_notify function..
   /// Update request for the object.
   ///
   /// @param state State that is changed
   /// @param ref The Object that caused the change
   ///
   void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_object_change_notify(state_, ref_));
   }

   /// @brief Set the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to the array of 16 Evas_Real values in column major order.
   ///
   /// Default projection matrix is identity matrix.
   ///
   /// @see evas_3d_camera_projection_perspective_set()
   /// @see evas_3d_camera_projection_ortho_set()
   /// @see evas_3d_camera_projection_frustum_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param matrix Projection Matrix
   ///
   void projection_matrix_set(const Evas_Real * matrix_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
   }

   /// @brief Get the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to receive the 16 Evas_Real values in column major order.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param[out] matrix Projection Matrix
   ///
   void projection_matrix_get(Evas_Real* matrix_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
   }

   /// @brief Set the projection matrix of the given camera with perspective projection.
   ///
   /// @param camera     The given camera.
   /// @param fovy       Field of view angle in Y direction.
   /// @param aspect     Aspect ratio.
   /// @param dnear      Distance to near clipping plane.
   /// @param dfar       Distance to far clipping plane.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param fovy Field of view angle in Y direction.
   /// @param aspect Aspect ratio.
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
   }

   /// @brief Set the projection matrix of the given camera with frustum projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
   }

   /// @brief Set the projection matrix of the given camera with orthogonal projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_CAMERA_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_ref(EVAS_3D_CAMERA_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _evas_3d_camera_update_notify_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->update_notify();
}

template <typename T>
void _evas_3d_camera_change_notify_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_3D_State state_, Evas_3D_Object * ref_)
{
   static_cast<T*>(self->this_)->change_notify(state_, ref_);
}

template <typename T>
void _evas_3d_camera_projection_matrix_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Real * matrix_)
{
   static_cast<T*>(self->this_)->projection_matrix_set(matrix_);
}

template <typename T>
void _evas_3d_camera_projection_matrix_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* matrix_)
{
   static_cast<T*>(self->this_)->projection_matrix_get(matrix_);
}

template <typename T>
void _evas_3d_camera_projection_perspective_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_perspective_set(fovy_, aspect_, dnear_, dfar_);
}

template <typename T>
void _evas_3d_camera_projection_frustum_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_);
}

template <typename T>
void _evas_3d_camera_projection_ortho_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_camera >
{
   template <typename T>
   struct type
   {
      virtual void update_notify()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_object_update_notify());
      }

      virtual void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_object_change_notify(state_, ref_));
      }

      virtual void projection_matrix_set(const Evas_Real * matrix_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_set(matrix_));
      }

      virtual void projection_matrix_get(Evas_Real* matrix_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_get(matrix_));
      }

      virtual void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      virtual void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

   };
};


template<>
struct operation_description_class_size< ::evas_3d_camera >
{
   static const int value = 7;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_3d_camera>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_camera_update_notify_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_object_update_notify);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_camera_change_notify_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_object_change_notify);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_perspective_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_perspective_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_frustum_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_frustum_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_ortho_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_ortho_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_3d_camera >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_3d_camera, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::evas_3d_camera >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_3d_camera, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::evas_3d_camera>
{
   template <typename U>
   struct type
   {
      operator ::evas_3d_camera() const
      {
         return ::evas_3d_camera(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void update_notify()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_object_update_notify());
      }

      void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_object_change_notify(state_, ref_));
      }

      void projection_matrix_set(const Evas_Real * matrix_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
      }

      void projection_matrix_get(Evas_Real* matrix_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
      }

      void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_3d_camera>)
{
   return (EVAS_3D_CAMERA_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_3D_CAMERA_HH

