#ifndef EFL_GENERATED_EVAS_3D_LIGHT_HH
#define EFL_GENERATED_EVAS_3D_LIGHT_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_3d_light.eo.h"
}

#include "evas_3d_object.eo.hh"
#include "evas_common_interface.eo.hh"

struct evas_3d_light
      : evas_3d_object,
      efl::eo::detail::extension_inheritance<evas::common_interface>::template type< ::evas_3d_light>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_3d_light(Eo* eo)
      : evas_3d_object(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit evas_3d_light(std::nullptr_t)
      : evas_3d_object(nullptr)
   {}

   /// @brief Call the object's constructor.
   /// Should not be used with #eo_do. Only use it with #eo_do_super.
   ///
   evas_3d_light(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : evas_3d_light(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   evas_3d_light(evas_3d_light const& other)
      : evas_3d_object(eo_ref(other._eo_ptr()))
   {}

   ~evas_3d_light() {}

   /// @brief Pure virtual update_notify function..
   /// Update request for the object.
   ///
   void update_notify() const
   {
      eo_do(_eo_ptr(), ::evas_3d_object_update_notify());
   }

   /// @brief Pure virtual change_notify function..
   /// Update request for the object.
   ///
   /// @param state State that is changed
   /// @param ref The Object that caused the change
   ///
   void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_object_change_notify(state_, ref_));
   }

   /// @brief Get the directional flag of the given light.
   ///
   /// @see evas_3d_light_directional_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param directional Whether the light is directional (@c EINA_TRUE), or not (@c EINA_FALSE).
   ///
   bool directional_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_3d_light_directional_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set the directional flag of the given light.
   ///
   /// Directional light is a type of light which is infinitely far away with no
   /// attenuation. The light direction is determined by the containing node's
   /// forward vector (negative Z-axis).
   ///
   /// By default, directional is not enabled.
   ///
   /// @see evas_3d_node_look_at_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param directional Whether the light is directional (@c EINA_TRUE), or not (@c EINA_FALSE).
   ///
   void directional_set(bool directional_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_directional_set(efl::eolian::to_c(directional_)));
   }

   /// @brief Get the spot exponent of the given light.
   ///
   /// @see evas_3d_light_spot_exponent_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param exponent Spot exponent value..
   ///
   Evas_Real spot_exponent_get() const
   {
      Evas_Real _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_3d_light_spot_exponent_get());
      return _tmp_ret;
   }

   /// @brief Set the spot exponent of the given light.
   ///
   /// Higher spot exponent means intensity at the center of the cone is relatively
   /// stronger. Zero exponent means the light intensity is evenly distibuted. The
   /// spot exponent has no effect when the light is not spot light (spot cutoff
   /// angle is less than 180 degree).
   ///
   /// Default spot exponent is 0.
   ///
   /// @see evas_3d_light_spot_cutoff_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param exponent Spot exponent value..
   ///
   void spot_exponent_set(Evas_Real exponent_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_spot_exponent_set(exponent_));
   }

   /// @brief Get the spot cutoff angle of the given light.
   ///
   /// @see evas_3d_light_spot_cutoff_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param cutoff Cutoff angle in degree..
   ///
   Evas_Real spot_cutoff_get() const
   {
      Evas_Real _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_3d_light_spot_cutoff_get());
      return _tmp_ret;
   }

   /// @brief Set the spot cutoff angle of the given light.
   ///
   /// Only angle less than 180 degree will make it spot light, so that other spot
   /// light attribute will take effect.
   ///
   /// Default spot cutoff angle is 180.
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param cutoff Cutoff angle in degree..
   ///
   void spot_cutoff_set(Evas_Real cutoff_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_spot_cutoff_set(cutoff_));
   }

   /// @brief Get the attenuation enable flag of the given light.
   ///
   /// @see evas_3d_light_attenuation_enable_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param enable Whether to enable attenuation (@c EINA_TRUE), or not (@c EINA_FALSE)..
   ///
   bool attenuation_enable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_3d_light_attenuation_enable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set the attenuation enable flag of the given light.
   ///
   /// By default, light attenuation is not enabled.
   ///
   /// @see evas_3d_light_attenuation_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param enable Whether to enable attenuation (@c EINA_TRUE), or not (@c EINA_FALSE)..
   ///
   void attenuation_enable_set(bool enable_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_attenuation_enable_set(efl::eolian::to_c(enable_)));
   }

   /// @brief Set the ambient color of the given light.
   ///
   /// Default ambient color is (0.0, 0.0, 0.0, 1.0).
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param r Red component of the ambient color between [0.0, 1.0].
   /// @param g Green component of the ambient color between [0.0, 1.0].
   /// @param b Blue component of the ambient color between [0.0, 1.0].
   /// @param a Alpha component of the ambient color between [0.0, 1.0].
   ///
   void ambient_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_ambient_set(r_, g_, b_, a_));
   }

   /// @brief Get the ambient color of the given light.
   ///
   /// @see evas_3d_light_ambient_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param[out] r Red component of the ambient color between [0.0, 1.0].
   /// @param[out] g Green component of the ambient color between [0.0, 1.0].
   /// @param[out] b Blue component of the ambient color between [0.0, 1.0].
   /// @param[out] a Alpha component of the ambient color between [0.0, 1.0].
   ///
   void ambient_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_ambient_get(r_, g_, b_, a_));
   }

   /// @brief Set the diffuse color of the given light.
   ///
   /// Default diffuse color is (1.0, 1.0, 1.0, 1.0).
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param r Red component of the diffuse color between [0.0, 1.0].
   /// @param g Green component of the diffuse color between [0.0, 1.0].
   /// @param b Blue component of the diffuse color between [0.0, 1.0].
   /// @param a Alpha component of the diffuse color between [0.0, 1.0].
   ///
   void diffuse_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_diffuse_set(r_, g_, b_, a_));
   }

   /// @brief Get the diffuse color of the given light.
   ///
   /// @see evas_3d_light_diffuse_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param[out] r Red component of the diffuse color between [0.0, 1.0].
   /// @param[out] g Green component of the diffuse color between [0.0, 1.0].
   /// @param[out] b Blue component of the diffuse color between [0.0, 1.0].
   /// @param[out] a Alpha component of the diffuse color between [0.0, 1.0].
   ///
   void diffuse_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_diffuse_get(r_, g_, b_, a_));
   }

   /// @brief Set the specular color of the given light.
   ///
   /// Default specular color is (1.0, 1.0, 1.0, 1.0).
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param r Red component of the specular color between [0.0, 1.0].
   /// @param g Green component of the specular color between [0.0, 1.0].
   /// @param b Blue component of the specular color between [0.0, 1.0].
   /// @param a Alpha component of the specular color between [0.0, 1.0].
   ///
   void specular_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_specular_set(r_, g_, b_, a_));
   }

   /// @brief Get the specular color of the given light.
   ///
   /// @see evas_3d_light_specular_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param[out] r Red component of the specular color between [0.0, 1.0].
   /// @param[out] g Green component of the specular color between [0.0, 1.0].
   /// @param[out] b Blue component of the specular color between [0.0, 1.0].
   /// @param[out] a Alpha component of the specular color between [0.0, 1.0].
   ///
   void specular_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_specular_get(r_, g_, b_, a_));
   }

   /// @brief Set the attenuation of the given light.
   ///
   /// Light attenuation has no effect with directional light. And the attenuation
   /// should be enabled first to take effect. The attenuation factor is calculated
   /// as follows.
   ///
   /// atten = 1.0 / constant + linear * distance + quadratic * distance * distance
   ///
   /// Default attenuation is constant = 1.0, linear = 0.0, quadratic = 0.0.
   ///
   /// @see evas_3d_light_attenuation_enable_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param constant Constant attenuation term..
   /// @param linear Linear attenuation term..
   /// @param quadratic Quadratic attenuation term..
   ///
   void attenuation_set(Evas_Real constant_, Evas_Real linear_, Evas_Real quadratic_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_attenuation_set(constant_, linear_, quadratic_));
   }

   /// @brief Get the attenuation of the given light.
   ///
   /// @see evas_3d_light_attenuation_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param[out] constant Constant attenuation term..
   /// @param[out] linear Linear attenuation term..
   /// @param[out] quadratic Quadratic attenuation term..
   ///
   void attenuation_get(Evas_Real* constant_, Evas_Real* linear_, Evas_Real* quadratic_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_attenuation_get(constant_, linear_, quadratic_));
   }

   /// @brief Set the projection matrix of the given light source.
   ///
   /// @param light The given light source.
   /// @param matrix Pointer to the array of 16 Evas_Real values in column major order.
   ///
   /// Default projection matrix is identity matrix.
   ///
   /// @see evas_3d_light_projection_perspective_set()
   /// @see evas_3d_light_projection_ortho_set()
   /// @see evas_3d_light_projection_frustum_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param matrix Projection Matrix
   ///
   void projection_matrix_set(const Evas_Real * matrix_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_projection_matrix_set(matrix_));
   }

   /// @brief Get the projection matrix of the given light source.
   ///
   /// @param light The given light source.
   /// @param matrix Pointer to receive the 16 Evas_Real values in column major order.
   ///
   /// @see evas_3d_light_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param[out] matrix Projection Matrix
   ///
   void projection_matrix_get(Evas_Real* matrix_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_projection_matrix_get(matrix_));
   }

   /// @brief Set the projection matrix of the given light source with perspective projection.
   ///
   /// @param light The given light source.
   /// @param fovy Field of view angle in Y direction.
   /// @param aspect Aspect ratio.
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   /// @see evas_3d_light_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param fovy Field of view angle in Y direction.
   /// @param aspect Aspect ratio.
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
   }

   /// @brief Set the projection matrix of the given light source with frustum projection.
   ///
   /// @see evas_3d_Light_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
   }

   /// @brief Set the projection matrix of the given light source with orthogonal projection.
   ///
   /// @see evas_3d_light_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Light
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
   {
      eo_do(_eo_ptr(), ::evas_3d_light_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_LIGHT_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_ref(EVAS_3D_LIGHT_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _evas_3d_light_update_notify_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->update_notify();
}

template <typename T>
void _evas_3d_light_change_notify_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_3D_State state_, Evas_3D_Object * ref_)
{
   static_cast<T*>(self->this_)->change_notify(state_, ref_);
}

template <typename T>
bool _evas_3d_light_directional_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->directional_get();
}

template <typename T>
void _evas_3d_light_directional_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool directional_)
{
   static_cast<T*>(self->this_)->directional_set(efl::eolian::to_cxx<bool>(directional_, std::tuple<std::false_type>()));
}

template <typename T>
Evas_Real _evas_3d_light_spot_exponent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->spot_exponent_get();
}

template <typename T>
void _evas_3d_light_spot_exponent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real exponent_)
{
   static_cast<T*>(self->this_)->spot_exponent_set(exponent_);
}

template <typename T>
Evas_Real _evas_3d_light_spot_cutoff_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->spot_cutoff_get();
}

template <typename T>
void _evas_3d_light_spot_cutoff_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real cutoff_)
{
   static_cast<T*>(self->this_)->spot_cutoff_set(cutoff_);
}

template <typename T>
bool _evas_3d_light_attenuation_enable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->attenuation_enable_get();
}

template <typename T>
void _evas_3d_light_attenuation_enable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enable_)
{
   static_cast<T*>(self->this_)->attenuation_enable_set(efl::eolian::to_cxx<bool>(enable_, std::tuple<std::false_type>()));
}

template <typename T>
void _evas_3d_light_ambient_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
{
   static_cast<T*>(self->this_)->ambient_set(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_ambient_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
{
   static_cast<T*>(self->this_)->ambient_get(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_diffuse_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
{
   static_cast<T*>(self->this_)->diffuse_set(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_diffuse_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
{
   static_cast<T*>(self->this_)->diffuse_get(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_specular_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
{
   static_cast<T*>(self->this_)->specular_set(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_specular_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
{
   static_cast<T*>(self->this_)->specular_get(r_, g_, b_, a_);
}

template <typename T>
void _evas_3d_light_attenuation_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real constant_, Evas_Real linear_, Evas_Real quadratic_)
{
   static_cast<T*>(self->this_)->attenuation_set(constant_, linear_, quadratic_);
}

template <typename T>
void _evas_3d_light_attenuation_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* constant_, Evas_Real* linear_, Evas_Real* quadratic_)
{
   static_cast<T*>(self->this_)->attenuation_get(constant_, linear_, quadratic_);
}

template <typename T>
void _evas_3d_light_projection_matrix_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Real * matrix_)
{
   static_cast<T*>(self->this_)->projection_matrix_set(matrix_);
}

template <typename T>
void _evas_3d_light_projection_matrix_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real* matrix_)
{
   static_cast<T*>(self->this_)->projection_matrix_get(matrix_);
}

template <typename T>
void _evas_3d_light_projection_perspective_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_perspective_set(fovy_, aspect_, dnear_, dfar_);
}

template <typename T>
void _evas_3d_light_projection_frustum_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_);
}

template <typename T>
void _evas_3d_light_projection_ortho_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   static_cast<T*>(self->this_)->projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_light >
{
   template <typename T>
   struct type
   {
      virtual void update_notify()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_object_update_notify());
      }

      virtual void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_object_change_notify(state_, ref_));
      }

      virtual bool directional_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_light_directional_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void directional_set(bool directional_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_directional_set(efl::eolian::to_c(directional_)));
      }

      virtual Evas_Real spot_exponent_get()
      {
         Evas_Real _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_light_spot_exponent_get());
            return _tmp_ret;
      }

      virtual void spot_exponent_set(Evas_Real exponent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_spot_exponent_set(exponent_));
      }

      virtual Evas_Real spot_cutoff_get()
      {
         Evas_Real _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_light_spot_cutoff_get());
            return _tmp_ret;
      }

      virtual void spot_cutoff_set(Evas_Real cutoff_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_spot_cutoff_set(cutoff_));
      }

      virtual bool attenuation_enable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_light_attenuation_enable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void attenuation_enable_set(bool enable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_attenuation_enable_set(efl::eolian::to_c(enable_)));
      }

      virtual void ambient_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_ambient_set(r_, g_, b_, a_));
      }

      virtual void ambient_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_ambient_get(r_, g_, b_, a_));
      }

      virtual void diffuse_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_diffuse_set(r_, g_, b_, a_));
      }

      virtual void diffuse_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_diffuse_get(r_, g_, b_, a_));
      }

      virtual void specular_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_specular_set(r_, g_, b_, a_));
      }

      virtual void specular_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_specular_get(r_, g_, b_, a_));
      }

      virtual void attenuation_set(Evas_Real constant_, Evas_Real linear_, Evas_Real quadratic_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_attenuation_set(constant_, linear_, quadratic_));
      }

      virtual void attenuation_get(Evas_Real* constant_, Evas_Real* linear_, Evas_Real* quadratic_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_attenuation_get(constant_, linear_, quadratic_));
      }

      virtual void projection_matrix_set(const Evas_Real * matrix_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_projection_matrix_set(matrix_));
      }

      virtual void projection_matrix_get(Evas_Real* matrix_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_projection_matrix_get(matrix_));
      }

      virtual void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      virtual void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_3d_light_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

   };
};


template<>
struct operation_description_class_size< ::evas_3d_light >
{
   static const int value = 23;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::evas_3d_light>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_light_update_notify_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_object_update_notify);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_light_change_notify_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_object_change_notify);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_light_directional_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_light_directional_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_light_directional_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_light_directional_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_light_spot_exponent_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_light_spot_exponent_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_light_spot_exponent_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_light_spot_exponent_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_evas_3d_light_spot_cutoff_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_3d_light_spot_cutoff_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_evas_3d_light_spot_cutoff_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_3d_light_spot_cutoff_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_evas_3d_light_attenuation_enable_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_3d_light_attenuation_enable_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_evas_3d_light_attenuation_enable_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_3d_light_attenuation_enable_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_evas_3d_light_ambient_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_3d_light_ambient_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_evas_3d_light_ambient_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_3d_light_ambient_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_evas_3d_light_diffuse_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_3d_light_diffuse_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_evas_3d_light_diffuse_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_3d_light_diffuse_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_evas_3d_light_specular_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_3d_light_specular_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_evas_3d_light_specular_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_3d_light_specular_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_evas_3d_light_attenuation_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_3d_light_attenuation_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_evas_3d_light_attenuation_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_3d_light_attenuation_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_evas_3d_light_projection_matrix_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_3d_light_projection_matrix_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_evas_3d_light_projection_matrix_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_3d_light_projection_matrix_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_evas_3d_light_projection_perspective_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_3d_light_projection_perspective_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_evas_3d_light_projection_frustum_set_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_3d_light_projection_frustum_set);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_evas_3d_light_projection_ortho_set_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_3d_light_projection_ortho_set);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::evas_3d_light >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_3d_light, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::evas_3d_light >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::evas_3d_light, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::evas_3d_light>
{
   template <typename U>
   struct type
   {
      operator ::evas_3d_light() const
      {
         return ::evas_3d_light(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void update_notify()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_object_update_notify());
      }

      void change_notify(Evas_3D_State state_, Evas_3D_Object * ref_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_object_change_notify(state_, ref_));
      }

      bool directional_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_3d_light_directional_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void directional_set(bool directional_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_directional_set(efl::eolian::to_c(directional_)));
      }

      Evas_Real spot_exponent_get()
      {
         Evas_Real _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_3d_light_spot_exponent_get());
            return _tmp_ret;
      }

      void spot_exponent_set(Evas_Real exponent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_spot_exponent_set(exponent_));
      }

      Evas_Real spot_cutoff_get()
      {
         Evas_Real _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_3d_light_spot_cutoff_get());
            return _tmp_ret;
      }

      void spot_cutoff_set(Evas_Real cutoff_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_spot_cutoff_set(cutoff_));
      }

      bool attenuation_enable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_3d_light_attenuation_enable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void attenuation_enable_set(bool enable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_attenuation_enable_set(efl::eolian::to_c(enable_)));
      }

      void ambient_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_ambient_set(r_, g_, b_, a_));
      }

      void ambient_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_ambient_get(r_, g_, b_, a_));
      }

      void diffuse_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_diffuse_set(r_, g_, b_, a_));
      }

      void diffuse_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_diffuse_get(r_, g_, b_, a_));
      }

      void specular_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_specular_set(r_, g_, b_, a_));
      }

      void specular_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_specular_get(r_, g_, b_, a_));
      }

      void attenuation_set(Evas_Real constant_, Evas_Real linear_, Evas_Real quadratic_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_attenuation_set(constant_, linear_, quadratic_));
      }

      void attenuation_get(Evas_Real* constant_, Evas_Real* linear_, Evas_Real* quadratic_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_attenuation_get(constant_, linear_, quadratic_));
      }

      void projection_matrix_set(const Evas_Real * matrix_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_projection_matrix_set(matrix_));
      }

      void projection_matrix_get(Evas_Real* matrix_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_projection_matrix_get(matrix_));
      }

      void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_3d_light_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::evas_3d_light>)
{
   return (EVAS_3D_LIGHT_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_3D_LIGHT_HH

