#ifndef EFL_GENERATED_EVAS_GRID_HH
#define EFL_GENERATED_EVAS_GRID_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_grid.eo.h"
}

#include "evas_smart_clipped.eo.hh"
#include <canvas/evas_object.eo.hh>

namespace evas {

struct grid
      : evas::smart_clipped
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit grid(Eo* eo)
      : evas::smart_clipped(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit grid(std::nullptr_t)
      : evas::smart_clipped(nullptr)
   {}

   /// @brief Call the object's constructor.
   /// Should not be used with #eo_do. Only use it with #eo_do_super.
   ///
   grid(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : grid(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   grid(grid const& other)
      : evas::smart_clipped(eo_ref(other._eo_ptr()))
   {}

   ~grid() {}

   /// @brief Gets the mirrored mode of the grid.
   ///
   /// @return @c EINA_TRUE if it's a mirrored grid, @c EINA_FALSE otherwise.
   /// @see evas_object_grid_mirrored_set()
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   bool mirrored_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_mirrored_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Sets the mirrored mode of the grid. In mirrored mode the grid items go
   /// from right to left instead of left to right. That is, 0,0 is top right, not
   /// to left.
   ///
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   void mirrored_set(bool mirrored_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_mirrored_set(efl::eolian::to_c(mirrored_)));
   }

   /// @brief Get the current virtual resolution
   ///
   /// @see evas_object_grid_size_set()
   /// @since 1.1
   ///
   /// @param w The virtual horizontal size (resolution) in integer units
   /// @param h The virtual vertical size (resolution) in integer units
   ///
   void size_get(int* w_, int* h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_size_get(w_, h_));
   }

   /// @brief Set the virtual resolution for the grid
   ///
   /// @since 1.1
   ///
   /// @param w The virtual horizontal size (resolution) in integer units
   /// @param h The virtual vertical size (resolution) in integer units
   ///
   void size_set(int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_size_set(w_, h_));
   }

   /// @brief Get the list of children for the grid.
   ///
   /// @note This is a duplicate of the list kept by the grid internally.
   /// It's up to the user to destroy it when it no longer needs it.
   /// It's possible to remove objects from the grid when walking this
   /// list, but these removals won't be reflected on it.
   /// @since 1.1
   ///
   efl::eina::list< evas::object > children_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_children_get());
      return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
   }

   /// @brief Get an accessor to get random access to the list of children for the grid.
   ///
   /// @note Do not remove or delete objects while walking the list.
   /// @since 1.1
   ///
   Eina_Accessor * accessor_new() const
   {
      Eina_Accessor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_accessor_new());
      return _tmp_ret;
   }

   /// @brief Faster way to remove all child objects from a grid object.
   ///
   /// @since 1.1
   ///
   /// @param clear if true, it will delete just removed children.
   ///
   void clear(bool clear_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_grid_clear(efl::eolian::to_c(clear_)));
   }

   /// @brief Get an iterator to walk the list of children for the grid.
   ///
   /// @note Do not remove or delete objects while walking the list.
   /// @since 1.1
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_iterator_new());
      return _tmp_ret;
   }

   /// @brief Create a grid that is child of a given element @a parent.
   ///
   /// @see evas_object_grid_add()
   /// @since 1.1
   ///
   evas::object add_to() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_add_to());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove child from grid.
   ///
   /// @note removing a child will immediately call a walk over children in order
   /// to recalculate numbers of columns and rows. If you plan to remove
   /// all children, use evas_object_grid_clear() instead.
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child 
   ///
   bool unpack(evas::object child_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_unpack(efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get the pack options for a grid child
   ///
   /// Get the pack x, y, width and height in virtual coordinates set by
   /// evas_object_grid_pack()
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The grid child to query for coordinates
   /// @param[out] x The pointer to where the x coordinate will be returned
   /// @param[out] y The pointer to where the y coordinate will be returned
   /// @param[out] w The pointer to where the width will be returned
   /// @param[out] h The pointer to where the height will be returned
   ///
   bool pack_get(evas::object child_, int* x_, int* y_, int* w_, int* h_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack_get(efl::eolian::to_c(child_), x_, y_, w_, h_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a new child to a grid object.
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The child object to add.
   /// @param x The virtual x coordinate of the child
   /// @param y The virtual y coordinate of the child
   /// @param w The virtual width of the child
   /// @param h The virtual height of the child
   ///
   bool pack(evas::object child_, int x_, int y_, int w_, int h_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack(efl::eolian::to_c(child_), x_, y_, w_, h_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_GRID_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_ref(EVAS_GRID_CLASS, _p._eo_raw, eo_constructor());
   }

};
} 

template <typename T>
bool evas_grid_mirrored_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mirrored_get();
}

template <typename T>
void evas_grid_mirrored_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mirrored_)
{
   static_cast<T*>(self->this_)->mirrored_set(efl::eolian::to_cxx<bool>(mirrored_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_grid_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w_, int* h_)
{
   static_cast<T*>(self->this_)->size_get(w_, h_);
}

template <typename T>
void evas_grid_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w_, int h_)
{
   static_cast<T*>(self->this_)->size_set(w_, h_);
}

template <typename T>
efl::eina::list< evas::object > evas_grid_children_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->children_get();
}

template <typename T>
Eina_Accessor * evas_grid_accessor_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->accessor_new();
}

template <typename T>
void evas_grid_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool clear_)
{
   static_cast<T*>(self->this_)->clear(efl::eolian::to_cxx<bool>(clear_, std::tuple<std::false_type>()));
}

template <typename T>
Eina_Iterator * evas_grid_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
evas::object evas_grid_add_to_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->add_to();
}

template <typename T>
bool evas_grid_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->unpack(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
bool evas_grid_pack_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_, int* x_, int* y_, int* w_, int* h_)
{
   return static_cast<T*>(self->this_)->pack_get(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), x_, y_, w_, h_);
}

template <typename T>
bool evas_grid_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_, int x_, int y_, int w_, int h_)
{
   return static_cast<T*>(self->this_)->pack(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), x_, y_, w_, h_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< evas::grid >
{
   template <typename T>
   struct type
   {
      virtual bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_mirrored_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void mirrored_set(bool mirrored_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_grid_mirrored_set(efl::eolian::to_c(mirrored_)));
      }

      virtual void size_get(int* w_, int* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_grid_size_get(w_, h_));
      }

      virtual void size_set(int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_grid_size_set(w_, h_));
      }

      virtual efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

      virtual Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_accessor_new());
            return _tmp_ret;
      }

      virtual void clear(bool clear_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_grid_clear(efl::eolian::to_c(clear_)));
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_iterator_new());
            return _tmp_ret;
      }

      virtual evas::object add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_add_to());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool unpack(evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_unpack(efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool pack_get(evas::object child_, int* x_, int* y_, int* w_, int* h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_pack_get(efl::eolian::to_c(child_), x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool pack(evas::object child_, int x_, int y_, int w_, int h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_grid_pack(efl::eolian::to_c(child_), x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< evas::grid >
{
   static const int value = 12;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<evas::grid>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_grid_mirrored_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_mirrored_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_grid_mirrored_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_mirrored_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_grid_size_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_size_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_grid_size_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_size_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_grid_children_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_children_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_grid_accessor_new_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_accessor_new);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_grid_clear_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_clear);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_grid_iterator_new_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_iterator_new);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_grid_add_to_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_add_to);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_grid_unpack_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_unpack);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_grid_pack_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_pack_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_grid_pack_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_grid_pack);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< evas::grid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::grid, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< evas::grid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::grid, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< evas::grid>
{
   template <typename U>
   struct type
   {
      operator evas::grid() const
      {
         return evas::grid(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_mirrored_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void mirrored_set(bool mirrored_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_grid_mirrored_set(efl::eolian::to_c(mirrored_)));
      }

      void size_get(int* w_, int* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_grid_size_get(w_, h_));
      }

      void size_set(int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_grid_size_set(w_, h_));
      }

      efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

      Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_accessor_new());
            return _tmp_ret;
      }

      void clear(bool clear_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_grid_clear(efl::eolian::to_c(clear_)));
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_iterator_new());
            return _tmp_ret;
      }

      evas::object add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_add_to());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool unpack(evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_unpack(efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool pack_get(evas::object child_, int* x_, int* y_, int* w_, int* h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack_get(efl::eolian::to_c(child_), x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool pack(evas::object child_, int x_, int y_, int w_, int h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_grid_pack(efl::eolian::to_c(child_), x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};

inline Eo_Class const* get_eo_class(tag<evas::grid>)
{
   return (EVAS_GRID_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_GRID_HH

