#ifndef EFL_GENERATED_EVAS_OBJECT_SMART_HH
#define EFL_GENERATED_EVAS_OBJECT_SMART_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_object_smart.eo.h"
}

#include "evas_object.eo.hh"
#include "evas_signal_interface.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

namespace evas {

struct object_smart
      : evas::object,
      efl::eo::detail::extension_inheritance<evas::signal_interface>::template type< ::evas::object_smart>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit object_smart(Eo* eo)
      : evas::object(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit object_smart(std::nullptr_t)
      : evas::object(nullptr)
   {}

   /// @brief Call the object's constructor.
   /// Should not be used with #eo_do. Only use it with #eo_do_super.
   ///
   object_smart(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : object_smart(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   object_smart(object_smart const& other)
      : evas::object(eo_ref(other._eo_ptr()))
   {}

   ~object_smart() {}

   /// @brief Checks whether a given smart object or any of its smart object
   /// parents is of a given smart class, <b>using pointer comparison</b>.
   ///
   /// @return @c EINA_TRUE, if @a obj or any of its parents is of type @a
   /// type, @c EINA_FALSE otherwise
   ///
   /// @see evas_object_smart_type_check() for more details
   /// @see eo_isa
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param type The type (name string) to check for. Must be the name
   ///
   bool smart_type_check_ptr(std::string type_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_type_check_ptr(efl::eolian::to_c(type_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Checks whether a given smart object or any of its smart object
   /// parents is of a given smart class.
   ///
   /// @return @c EINA_TRUE, if @a obj or any of its parents is of type @a
   /// type, @c EINA_FALSE otherwise
   ///
   /// If @p obj is not a smart object, this call will fail
   /// immediately.
   ///
   /// This function supports Eo and legacy inheritance mechanisms. However,
   /// it is recommended to use eo_isa instead if your object is using Eo from
   /// top to bottom.
   ///
   /// The checks use smart classes names and <b>string
   /// comparison</b>. There is a version of this same check using
   /// <b>pointer comparison</b>, since a smart class' name is a single
   /// string in Evas.
   ///
   /// @see evas_object_smart_type_check_ptr()
   /// @see eo_isa
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param type The @b name (type) of the smart class to check for
   ///
   bool smart_type_check(std::string type_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_type_check(efl::eolian::to_c(type_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Retrieve user data stored on a given smart object.
   ///
   /// @return A pointer to data stored using
   /// evas_object_smart_data_set(), or @c NULL, if none has been
   /// set.
   ///
   /// @see evas_object_smart_data_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void * smart_data_get() const
   {
      void * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_data_get());
      return _tmp_ret;
   }

   /// @brief Get the value of the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// @return if flag is set or not.
   ///
   /// @note this flag will be unset during the rendering phase, when the
   /// @c calculate() smart function is called, if one is provided.
   /// If it's not provided, then the flag will be left unchanged
   /// after the rendering phase.
   ///
   /// @see evas_object_smart_need_recalculate_set(), for more details
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   bool need_recalculate_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set or unset the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// If this flag is set, then the @c calculate() smart function of @p
   /// obj will be called, if one is provided, during rendering phase of
   /// Evas (see evas_render()), after which this flag will be
   /// automatically unset.
   ///
   /// If that smart function is not provided for the given object, this
   /// flag will be left unchanged.
   ///
   /// @note just setting this flag will not make the canvas' whole scene
   /// dirty, by itself, and evas_render() will have no effect. To
   /// force that, use evas_object_smart_changed(), that will also
   /// call this function automatically, with @c EINA_TRUE as parameter.
   ///
   /// @see evas_object_smart_need_recalculate_get()
   /// @see evas_object_smart_calculate()
   /// @see evas_smart_objects_calculate()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   void need_recalculate_set(bool value_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_need_recalculate_set(efl::eolian::to_c(value_)));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param clip 
   ///
   void clip_set(evas::object clip_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_clip_set(efl::eolian::to_c(clip_)));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param r 
   /// @param g 
   /// @param b 
   /// @param a 
   ///
   void color_set(int r_, int g_, int b_, int a_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_color_set(r_, g_, b_, a_));
   }

   /// @brief Store a pointer to user data for a given smart object.
   ///
   /// This data is stored @b independently of the one set by
   /// evas_object_data_set(), naturally.
   ///
   /// @see evas_object_smart_data_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param data A pointer to user data
   ///
   void data_set(void * data_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_data_set(data_));
   }

   /// @brief Retrieves the list of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the list of the member objects of @p obj.
   ///
   /// The returned list should be freed with @c eina_list_free() when you
   /// no longer need it.
   ///
   /// @since 1.7 This function will return @c NULL when a non-smart object is passed.
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_iterator_new()
   ///
   efl::eina::range_list< evas::object > members_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
      return efl::eolian::to_cxx<efl::eina::range_list< evas::object >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
   }

   /// @brief Get the #Evas_Smart from which @p obj smart object was created.
   ///
   /// @return the #Evas_Smart handle or @c NULL, on errors
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   Evas_Smart * smart_get() const
   {
      Evas_Smart * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_get());
      return _tmp_ret;
   }

   /// @brief No description supplied by the EAPI.
   ///
   void show() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_show());
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param x 
   /// @param y 
   ///
   void move(Evas_Coord x_, Evas_Coord y_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_move(x_, y_));
   }

   /// @brief Set an smart object @b instance's smart callbacks descriptions.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE on failure.
   ///
   /// These descriptions are hints to be used by introspection and are
   /// not enforced in any way.
   ///
   /// It will not be checked if instance callbacks descriptions have the
   /// same name as respective possibly registered in the smart object
   /// @b class. Both are kept in different arrays and users of
   /// evas_object_smart_callbacks_descriptions_get() should handle this
   /// case as they wish.
   ///
   /// @note Becase @p descriptions must be @c NULL terminated, and
   /// because a @c NULL name makes little sense, too,
   /// Evas_Smart_Cb_Description.name must @b not be @c NULL.
   ///
   /// @note While instance callbacks descriptions are possible, they are
   /// @b not recommended. Use @b class callbacks descriptions
   /// instead as they make you smart object user's life simpler and
   /// will use less memory, as descriptions and arrays will be
   /// shared among all instances.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param descriptions @c NULL terminated array with
   /// #Evas_Smart_Cb_Description descriptions. Array elements won't be
   /// modified at run time, but references to them and their contents
   /// will be made, so this array should be kept alive during the whole
   /// object's lifetime.
   ///
   bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Retrieve an smart object's know smart callback descriptions (both
   /// instance and class ones).
   ///
   /// This call searches for registered callback descriptions for both
   /// instance and class of the given smart object. These arrays will be
   /// sorted by Evas_Smart_Cb_Description.name and also @c NULL
   /// terminated, so both @a class_count and @a instance_count can be
   /// ignored, if the caller wishes so. The terminator @c NULL is not
   /// counted in these values.
   ///
   /// @note If just class descriptions are of interest, try
   /// evas_smart_callbacks_descriptions_get() instead.
   ///
   /// @note Use @c NULL pointers on the descriptions/counters you're not
   /// interested in: they'll be ignored by the function.
   ///
   /// @see evas_smart_callbacks_descriptions_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param[out] class_descriptions Where to store class callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned
   /// @param[out] class_count Returns how many class callbacks descriptions
   /// are known.
   /// @param[out] instance_descriptions Where to store instance callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned.
   /// @param[out] instance_count Returns how many instance callbacks
   /// descriptions are known.
   ///
   void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
   }

   /// @brief Retrieves an iterator of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the iterator of the member objects of @p obj.
   ///
   /// @since 1.8
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
      return _tmp_ret;
   }

   /// @brief Find callback description for callback called @a name.
   ///
   /// or @c NULL if not found. If parameter is @c NULL, no search
   /// will be done on instance descriptions.
   /// @return reference to description if found, @c NULL if not found.
   ///
   /// @param name name of desired callback, must @b not be @c NULL.  The
   /// search have a special case for @a name being the same
   /// pointer as registered with Evas_Smart_Cb_Description, one
   /// can use it to avoid excessive use of strcmp().
   /// @param[out] class_description pointer to return class description or
   /// @c NULL if not found. If parameter is @c NULL, no search will
   /// be done on class descriptions.
   /// @param[out] instance_description pointer to return instance description
   ///
   void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_callback_description_find(efl::eolian::to_c(name_), class_description_, instance_description_));
   }

   /// @brief No description supplied by the EAPI.
   ///
   void hide() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_hide());
   }

   /// @brief Call the @b calculate() smart function immediately on a given smart
   /// object.
   ///
   /// This will force immediate calculations (see #Evas_Smart_Class)
   /// needed for renderization of this object and, besides, unset the
   /// flag on it telling it needs recalculation for the next rendering
   /// phase.
   ///
   /// @see evas_object_smart_need_recalculate_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void calculate() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_calculate());
   }

   /// @brief Instantiates a new smart object described by @p s.
   ///
   /// @return a new #Evas_Object handle
   ///
   /// This is the function one should use when defining the public
   /// function @b adding an instance of the new smart object to a given
   /// canvas. It will take care of setting all of its internals to work
   /// as they should, if the user set things properly, as seem on the
   /// #EVAS_SMART_SUBCLASS_NEW, for example.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void add() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_add());
   }

   /// @brief Set an Evas object as a member of a given smart object.
   ///
   /// Members will automatically be stacked and layered together with the
   /// smart object. The various stacking functions will operate on
   /// members relative to the other members instead of the entire canvas,
   /// since they now live on an exclusive layer (see
   /// evas_object_stack_above(), for more details).
   ///
   /// Any @p smart_obj object's specific implementation of the @c
   /// member_add() smart function will take place too, naturally.
   ///
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param sub_obj The member object
   ///
   void member_add(evas::object sub_obj_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_member_add(efl::eolian::to_c(sub_obj_)));
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param w 
   /// @param h 
   ///
   void resize(Evas_Coord w_, Evas_Coord h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
   }

   /// @brief No description supplied by the EAPI.
   ///
   void clip_unset() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_clip_unset());
   }

   /// @brief Mark smart object as changed, dirty.
   ///
   /// This will flag the given object as needing recalculation,
   /// forcefully. As an effect, on the next rendering cycle its @b
   /// calculate() (see #Evas_Smart_Class) smart function will be called.
   ///
   /// @see evas_object_smart_need_recalculate_set().
   /// @see evas_object_smart_calculate().
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void changed() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_changed());
   }

   /// @brief Removes a member object from a given smart object.
   ///
   /// This removes a member object from a smart object, if it was added
   /// to any. The object will still be on the canvas, but no longer
   /// associated with whichever smart object it was associated with.
   ///
   /// @see evas_object_smart_member_add() for more details
   /// @see evas_object_smart_members_get()
   ///
   /// @param sub_obj the member object
   /// @ingroup Evas_Smart_Object_Group
   ///
   void member_del(evas::object sub_obj_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_member_del(efl::eolian::to_c(sub_obj_)));
   }

   /// @brief Deletes a smart object.
   ///
   void del() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_del());
   }

   /// @brief Attach a given smart data to a given smart object.
   ///
   /// @param s 
   ///
   void attach(Evas_Smart * s_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_attach(s_));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJECT_SMART_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_ref(EVAS_OBJECT_SMART_CLASS, _p._eo_raw, eo_constructor());
   }

};
} 

template <typename T>
bool evas_object_smart_smart_type_check_ptr_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * type_)
{
   return static_cast<T*>(self->this_)->smart_type_check_ptr(efl::eolian::to_cxx<std::string>(type_, std::tuple<std::false_type>()));
}

template <typename T>
bool evas_object_smart_smart_type_check_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * type_)
{
   return static_cast<T*>(self->this_)->smart_type_check(efl::eolian::to_cxx<std::string>(type_, std::tuple<std::false_type>()));
}

template <typename T>
void * evas_object_smart_smart_data_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->smart_data_get();
}

template <typename T>
bool evas_object_smart_need_recalculate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->need_recalculate_get();
}

template <typename T>
void evas_object_smart_need_recalculate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool value_)
{
   static_cast<T*>(self->this_)->need_recalculate_set(efl::eolian::to_cxx<bool>(value_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_object_smart_clip_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * clip_)
{
   static_cast<T*>(self->this_)->clip_set(efl::eolian::to_cxx<evas::object>(clip_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_object_smart_color_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int r_, int g_, int b_, int a_)
{
   static_cast<T*>(self->this_)->color_set(r_, g_, b_, a_);
}

template <typename T>
void evas_object_smart_data_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void * data_)
{
   static_cast<T*>(self->this_)->data_set(data_);
}

template <typename T>
efl::eina::range_list< evas::object > evas_object_smart_members_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->members_get();
}

template <typename T>
Evas_Smart * evas_object_smart_smart_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->smart_get();
}

template <typename T>
void evas_object_smart_show_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->show();
}

template <typename T>
void evas_object_smart_move_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_)
{
   static_cast<T*>(self->this_)->move(x_, y_);
}

template <typename T>
bool evas_object_smart_callbacks_descriptions_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description * descriptions_)
{
   return static_cast<T*>(self->this_)->callbacks_descriptions_set(descriptions_);
}

template <typename T>
void evas_object_smart_callbacks_descriptions_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_)
{
   static_cast<T*>(self->this_)->callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_);
}

template <typename T>
Eina_Iterator * evas_object_smart_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
void evas_object_smart_callback_description_find_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_)
{
   static_cast<T*>(self->this_)->callback_description_find(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), class_description_, instance_description_);
}

template <typename T>
void evas_object_smart_hide_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->hide();
}

template <typename T>
void evas_object_smart_calculate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->calculate();
}

template <typename T>
void evas_object_smart_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->add();
}

template <typename T>
void evas_object_smart_member_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj_)
{
   static_cast<T*>(self->this_)->member_add(efl::eolian::to_cxx<evas::object>(sub_obj_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_object_smart_resize_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w_, Evas_Coord h_)
{
   static_cast<T*>(self->this_)->resize(w_, h_);
}

template <typename T>
void evas_object_smart_clip_unset_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clip_unset();
}

template <typename T>
void evas_object_smart_changed_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->changed();
}

template <typename T>
void evas_object_smart_member_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj_)
{
   static_cast<T*>(self->this_)->member_del(efl::eolian::to_cxx<evas::object>(sub_obj_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_object_smart_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->del();
}

template <typename T>
void evas_object_smart_attach_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Smart * s_)
{
   static_cast<T*>(self->this_)->attach(s_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< evas::object_smart >
{
   template <typename T>
   struct type
   {
      virtual bool smart_type_check_ptr(std::string type_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_type_check_ptr(efl::eolian::to_c(type_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool smart_type_check(std::string type_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_type_check(efl::eolian::to_c(type_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void * smart_data_get()
      {
         void * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_data_get());
            return _tmp_ret;
      }

      virtual bool need_recalculate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_need_recalculate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void need_recalculate_set(bool value_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_need_recalculate_set(efl::eolian::to_c(value_)));
      }

      virtual void clip_set(evas::object clip_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_clip_set(efl::eolian::to_c(clip_)));
      }

      virtual void color_set(int r_, int g_, int b_, int a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_color_set(r_, g_, b_, a_));
      }

      virtual void data_set(void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_data_set(data_));
      }

      virtual efl::eina::range_list< evas::object > members_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_members_get());
            return efl::eolian::to_cxx<efl::eina::range_list< evas::object >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
      }

      virtual Evas_Smart * smart_get()
      {
         Evas_Smart * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_get());
            return _tmp_ret;
      }

      virtual void show()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_show());
      }

      virtual void move(Evas_Coord x_, Evas_Coord y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_move(x_, y_));
      }

      virtual bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_iterator_new());
            return _tmp_ret;
      }

      virtual void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_callback_description_find(efl::eolian::to_c(name_), class_description_, instance_description_));
      }

      virtual void hide()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_hide());
      }

      virtual void calculate()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_calculate());
      }

      virtual void add()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_add());
      }

      virtual void member_add(evas::object sub_obj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_member_add(efl::eolian::to_c(sub_obj_)));
      }

      virtual void resize(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_resize(w_, h_));
      }

      virtual void clip_unset()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_clip_unset());
      }

      virtual void changed()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_changed());
      }

      virtual void member_del(evas::object sub_obj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_member_del(efl::eolian::to_c(sub_obj_)));
      }

      virtual void del()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_del());
      }

      virtual void attach(Evas_Smart * s_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_attach(s_));
      }

   };
};


template<>
struct operation_description_class_size< evas::object_smart >
{
   static const int value = 26;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<evas::object_smart>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_object_smart_smart_type_check_ptr_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_type_check_ptr);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_object_smart_smart_type_check_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_type_check);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_object_smart_smart_data_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_data_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_object_smart_need_recalculate_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_object_smart_need_recalculate_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_object_smart_clip_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_object_smart_color_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_color_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_object_smart_data_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_data_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_object_smart_members_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_members_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_object_smart_smart_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_object_smart_show_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_show);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_object_smart_move_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_move);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_object_smart_callbacks_descriptions_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_object_smart_callbacks_descriptions_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_object_smart_iterator_new_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_iterator_new);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_object_smart_callback_description_find_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callback_description_find);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_object_smart_hide_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_hide);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_object_smart_calculate_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_calculate);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_object_smart_add_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_add);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_object_smart_member_add_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_add);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_object_smart_resize_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_resize);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_object_smart_clip_unset_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_unset);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::evas_object_smart_changed_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_changed);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::evas_object_smart_member_del_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_del);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::evas_object_smart_del_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_del);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::evas_object_smart_attach_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_attach);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< evas::object_smart >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::object_smart, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< evas::object_smart >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::object_smart, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< evas::object_smart>
{
   template <typename U>
   struct type
   {
      operator evas::object_smart() const
      {
         return evas::object_smart(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool smart_type_check_ptr(std::string type_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_type_check_ptr(efl::eolian::to_c(type_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool smart_type_check(std::string type_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_type_check(efl::eolian::to_c(type_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void * smart_data_get()
      {
         void * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_data_get());
            return _tmp_ret;
      }

      bool need_recalculate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void need_recalculate_set(bool value_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_need_recalculate_set(efl::eolian::to_c(value_)));
      }

      void clip_set(evas::object clip_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_clip_set(efl::eolian::to_c(clip_)));
      }

      void color_set(int r_, int g_, int b_, int a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_color_set(r_, g_, b_, a_));
      }

      void data_set(void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_data_set(data_));
      }

      efl::eina::range_list< evas::object > members_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
            return efl::eolian::to_cxx<efl::eina::range_list< evas::object >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
      }

      Evas_Smart * smart_get()
      {
         Evas_Smart * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_get());
            return _tmp_ret;
      }

      void show()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_show());
      }

      void move(Evas_Coord x_, Evas_Coord y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_move(x_, y_));
      }

      bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
            return _tmp_ret;
      }

      void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_callback_description_find(efl::eolian::to_c(name_), class_description_, instance_description_));
      }

      void hide()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_hide());
      }

      void calculate()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_calculate());
      }

      void add()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_add());
      }

      void member_add(evas::object sub_obj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_member_add(efl::eolian::to_c(sub_obj_)));
      }

      void resize(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
      }

      void clip_unset()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_clip_unset());
      }

      void changed()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_changed());
      }

      void member_del(evas::object sub_obj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_member_del(efl::eolian::to_c(sub_obj_)));
      }

      void del()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_del());
      }

      void attach(Evas_Smart * s_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_attach(s_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<evas::object_smart>)
{
   return (EVAS_OBJECT_SMART_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_OBJECT_SMART_HH

