#ifndef EFL_GENERATED_EVAS_TABLE_HH
#define EFL_GENERATED_EVAS_TABLE_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_table.eo.h"
}

#include "evas_smart_clipped.eo.hh"
#include <canvas/evas_object.eo.hh>

namespace evas {

struct table
      : evas::smart_clipped
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit table(Eo* eo)
      : evas::smart_clipped(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit table(std::nullptr_t)
      : evas::smart_clipped(nullptr)
   {}

   /// @brief Call the object's constructor.
   /// Should not be used with #eo_do. Only use it with #eo_do_super.
   ///
   table(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : table(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   table(table const& other)
      : evas::smart_clipped(eo_ref(other._eo_ptr()))
   {}

   ~table() {}

   /// @brief Instantiates a new smart object described by @p s.
   ///
   /// @return a new #Evas_Object handle
   ///
   /// This is the function one should use when defining the public
   /// function @b adding an instance of the new smart object to a given
   /// canvas. It will take care of setting all of its internals to work
   /// as they should, if the user set things properly, as seem on the
   /// #EVAS_SMART_SUBCLASS_NEW, for example.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void add() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_add());
   }

   /// @brief Deletes a smart object.
   ///
   void del() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_del());
   }

   /// @brief Call the @b calculate() smart function immediately on a given smart
   /// object.
   ///
   /// This will force immediate calculations (see #Evas_Smart_Class)
   /// needed for renderization of this object and, besides, unset the
   /// flag on it telling it needs recalculation for the next rendering
   /// phase.
   ///
   /// @see evas_object_smart_need_recalculate_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void calculate() const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_calculate());
   }

   /// @brief No description supplied by the EAPI.
   ///
   /// @param w 
   /// @param h 
   ///
   void resize(Evas_Coord w_, Evas_Coord h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
   }

   /// @brief Get the current layout homogeneous mode.
   ///
   /// @see evas_object_table_homogeneous_set()
   ///
   /// @param homogeneous 
   ///
   Evas_Object_Table_Homogeneous_Mode homogeneous_get() const
   {
      Evas_Object_Table_Homogeneous_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_homogeneous_get());
      return _tmp_ret;
   }

   /// @brief @brief Set how this table should layout children.
   ///
   /// @todo consider aspect hint and respect it.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_NONE
   /// If table does not use homogeneous mode then columns and rows will
   /// be calculated based on hints of individual cells. This operation
   /// mode is more flexible, but more complex and heavy to calculate as
   /// well. @b Weight properties are handled as a boolean expand. Negative
   /// alignment will be considered as 0.5. This is the default.
   ///
   /// @todo @c EVAS_OBJECT_TABLE_HOMOGENEOUS_NONE should balance weight.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_TABLE
   /// When homogeneous is relative to table the own table size is divided
   /// equally among children, filling the whole table area. That is, if
   /// table has @c WIDTH and @c COLUMNS, each cell will get <tt>WIDTH /
   /// COLUMNS</tt> pixels. If children have minimum size that is larger
   /// than this amount (including padding), then it will overflow and be
   /// aligned respecting the alignment hint, possible overlapping sibling
   /// cells. @b Weight hint is used as a boolean, if greater than zero it
   /// will make the child expand in that axis, taking as much space as
   /// possible (bounded to maximum size hint). Negative alignment will be
   /// considered as 0.5.
   ///
   /// @par EVAS_OBJECT_TABLE_HOMOGENEOUS_ITEM
   /// When homogeneous is relative to item it means the greatest minimum
   /// cell size will be used. That is, if no element is set to expand,
   /// the table will have its contents to a minimum size, the bounding
   /// box of all these children will be aligned relatively to the table
   /// object using evas_object_table_align_get(). If the table area is
   /// too small to hold this minimum bounding box, then the objects will
   /// keep their size and the bounding box will overflow the box area,
   /// still respecting the alignment. @b Weight hint is used as a
   /// boolean, if greater than zero it will make that cell expand in that
   /// axis, toggling the <b>expand mode</b>, which makes the table behave
   /// much like @b EVAS_OBJECT_TABLE_HOMOGENEOUS_TABLE, except that the
   /// bounding box will overflow and items will not overlap siblings. If
   /// no minimum size is provided at all then the table will fallback to
   /// expand mode as well.
   ///
   /// @param homogeneous 
   ///
   void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_homogeneous_set(homogeneous_));
   }

   /// @brief Get alignment of the whole bounding box of contents.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void align_get(double* horizontal_, double* vertical_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_align_get(horizontal_, vertical_));
   }

   /// @brief Set the alignment of the whole bounding box of contents.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void align_set(double horizontal_, double vertical_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_align_set(horizontal_, vertical_));
   }

   /// @brief Get padding between cells.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_padding_get(horizontal_, vertical_));
   }

   /// @brief Set padding between cells.
   ///
   /// @param horizontal 
   /// @param vertical 
   ///
   void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_padding_set(horizontal_, vertical_));
   }

   /// @brief Gets the mirrored mode of the table.
   ///
   /// @return @c EINA_TRUE if it's a mirrored table, @c EINA_FALSE otherwise.
   /// @since 1.1
   /// @see evas_object_table_mirrored_set()
   ///
   /// @param mirrored the mirrored mode to set
   ///
   bool mirrored_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_mirrored_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Sets the mirrored mode of the table. In mirrored mode the table items go
   /// from right to left instead of left to right. That is, 1,1 is top right, not
   /// top left.
   ///
   /// @since 1.1
   ///
   /// @param mirrored the mirrored mode to set
   ///
   void mirrored_set(bool mirrored_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_mirrored_set(efl::eolian::to_c(mirrored_)));
   }

   /// @brief Get the number of columns and rows this table takes.
   ///
   /// @note columns and rows are virtual entities, one can specify a table
   /// with a single object that takes 4 columns and 5 rows. The only
   /// difference for a single cell table is that paddings will be
   /// accounted proportionally.
   ///
   /// @param cols 
   /// @param rows 
   ///
   void col_row_size_get(int* cols_, int* rows_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_col_row_size_get(cols_, rows_));
   }

   /// @brief Get the list of children for the table.
   ///
   /// @note This is a duplicate of the list kept by the table internally.
   /// It's up to the user to destroy it when it no longer needs it.
   /// It's possible to remove objects from the table when walking this
   /// list, but these removals won't be reflected on it.
   ///
   efl::eina::list< evas::object > children_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_children_get());
      return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
   }

   /// @brief Get the child of the table at the given coordinates
   ///
   /// @note This does not take into account col/row spanning
   ///
   /// @param child 
   ///
   evas::object child_get(unsigned short col_, unsigned short row_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_child_get(col_, row_));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Faster way to remove all child objects from a table object.
   ///
   /// @param clear if true, it will delete just removed children.
   ///
   void clear(bool clear_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_table_clear(efl::eolian::to_c(clear_)));
   }

   /// @brief Get an accessor to get random access to the list of children for the table.
   ///
   /// @note Do not remove or delete objects while walking the list.
   ///
   Eina_Accessor * accessor_new() const
   {
      Eina_Accessor * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_accessor_new());
      return _tmp_ret;
   }

   /// @brief Get an iterator to walk the list of children for the table.
   ///
   /// @note Do not remove or delete objects while walking the list.
   ///
   Eina_Iterator * iterator_new() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_iterator_new());
      return _tmp_ret;
   }

   /// @brief @brief Create a table that is child of a given element @a parent.
   ///
   /// @see evas_object_table_add()
   ///
   evas::object add_to() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_add_to());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get packing location of a child of table
   ///
   /// @return 1 on success, 0 on failure.
   /// @since 1.1
   ///
   /// @param child The child object to add.
   /// @param[out] col pointer to store relative-horizontal position to place child.
   /// @param[out] row pointer to store relative-vertical position to place child.
   /// @param[out] colspan pointer to store how many relative-horizontal position to use for this child.
   /// @param[out] rowspan pointer to store how many relative-vertical position to use for this child.
   ///
   bool pack_get(evas::object child_, unsigned short* col_, unsigned short* row_, unsigned short* colspan_, unsigned short* rowspan_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_pack_get(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a new child to a table object or set its current packing.
   ///
   /// Note that columns and rows only guarantee 16bit unsigned values at best.
   /// That means that col + colspan AND row + rowspan must fit inside 16bit
   /// unsigned values cleanly. You will be warned once values exceed 15bit
   /// storage, and attempting to use values not able to fit in 16bits will
   /// result in failure.
   ///
   /// @return 1 on success, 0 on failure.
   ///
   /// @param child The child object to add.
   /// @param col relative-horizontal position to place child.
   /// @param row relative-vertical position to place child.
   /// @param colspan how many relative-horizontal position to use for this child.
   /// @param rowspan how many relative-vertical position to use for this child.
   ///
   bool pack(evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_pack(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove child from table.
   ///
   /// @note removing a child will immediately call a walk over children in order
   /// to recalculate numbers of columns and rows. If you plan to remove
   /// all children, use evas_object_table_clear() instead.
   ///
   /// @return 1 on success, 0 on failure.
   ///
   /// @param child 
   ///
   bool unpack(evas::object child_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_table_unpack(efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_TABLE_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_ref(EVAS_TABLE_CLASS, _p._eo_raw, eo_constructor());
   }

};
} 

template <typename T>
void evas_table_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->add();
}

template <typename T>
void evas_table_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->del();
}

template <typename T>
void evas_table_calculate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->calculate();
}

template <typename T>
void evas_table_resize_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w_, Evas_Coord h_)
{
   static_cast<T*>(self->this_)->resize(w_, h_);
}

template <typename T>
Evas_Object_Table_Homogeneous_Mode evas_table_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void evas_table_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object_Table_Homogeneous_Mode homogeneous_)
{
   static_cast<T*>(self->this_)->homogeneous_set(homogeneous_);
}

template <typename T>
void evas_table_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* horizontal_, double* vertical_)
{
   static_cast<T*>(self->this_)->align_get(horizontal_, vertical_);
}

template <typename T>
void evas_table_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double horizontal_, double vertical_)
{
   static_cast<T*>(self->this_)->align_set(horizontal_, vertical_);
}

template <typename T>
void evas_table_padding_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* horizontal_, Evas_Coord* vertical_)
{
   static_cast<T*>(self->this_)->padding_get(horizontal_, vertical_);
}

template <typename T>
void evas_table_padding_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord horizontal_, Evas_Coord vertical_)
{
   static_cast<T*>(self->this_)->padding_set(horizontal_, vertical_);
}

template <typename T>
bool evas_table_mirrored_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mirrored_get();
}

template <typename T>
void evas_table_mirrored_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mirrored_)
{
   static_cast<T*>(self->this_)->mirrored_set(efl::eolian::to_cxx<bool>(mirrored_, std::tuple<std::false_type>()));
}

template <typename T>
void evas_table_col_row_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* cols_, int* rows_)
{
   static_cast<T*>(self->this_)->col_row_size_get(cols_, rows_);
}

template <typename T>
efl::eina::list< evas::object > evas_table_children_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->children_get();
}

template <typename T>
evas::object evas_table_child_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned short col_, unsigned short row_)
{
   return static_cast<T*>(self->this_)->child_get(col_, row_);
}

template <typename T>
void evas_table_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool clear_)
{
   static_cast<T*>(self->this_)->clear(efl::eolian::to_cxx<bool>(clear_, std::tuple<std::false_type>()));
}

template <typename T>
Eina_Accessor * evas_table_accessor_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->accessor_new();
}

template <typename T>
Eina_Iterator * evas_table_iterator_new_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iterator_new();
}

template <typename T>
evas::object evas_table_add_to_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->add_to();
}

template <typename T>
bool evas_table_pack_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_, unsigned short* col_, unsigned short* row_, unsigned short* colspan_, unsigned short* rowspan_)
{
   return static_cast<T*>(self->this_)->pack_get(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), col_, row_, colspan_, rowspan_);
}

template <typename T>
bool evas_table_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
{
   return static_cast<T*>(self->this_)->pack(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), col_, row_, colspan_, rowspan_);
}

template <typename T>
bool evas_table_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->unpack(efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< evas::table >
{
   template <typename T>
   struct type
   {
      virtual void add()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_add());
      }

      virtual void del()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_del());
      }

      virtual void calculate()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_calculate());
      }

      virtual void resize(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_resize(w_, h_));
      }

      virtual Evas_Object_Table_Homogeneous_Mode homogeneous_get()
      {
         Evas_Object_Table_Homogeneous_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_homogeneous_get());
            return _tmp_ret;
      }

      virtual void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_homogeneous_set(homogeneous_));
      }

      virtual void align_get(double* horizontal_, double* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_align_get(horizontal_, vertical_));
      }

      virtual void align_set(double horizontal_, double vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_align_set(horizontal_, vertical_));
      }

      virtual void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_padding_get(horizontal_, vertical_));
      }

      virtual void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_padding_set(horizontal_, vertical_));
      }

      virtual bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_mirrored_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void mirrored_set(bool mirrored_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_mirrored_set(efl::eolian::to_c(mirrored_)));
      }

      virtual void col_row_size_get(int* cols_, int* rows_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_col_row_size_get(cols_, rows_));
      }

      virtual efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

      virtual evas::object child_get(unsigned short col_, unsigned short row_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_child_get(col_, row_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void clear(bool clear_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_table_clear(efl::eolian::to_c(clear_)));
      }

      virtual Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_accessor_new());
            return _tmp_ret;
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_iterator_new());
            return _tmp_ret;
      }

      virtual evas::object add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_add_to());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool pack_get(evas::object child_, unsigned short* col_, unsigned short* row_, unsigned short* colspan_, unsigned short* rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_pack_get(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool pack(evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_pack(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool unpack(evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_table_unpack(efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< evas::table >
{
   static const int value = 22;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<evas::table>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_table_add_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_add);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_table_del_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_del);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_table_calculate_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_calculate);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_table_resize_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_resize);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_table_homogeneous_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_table_homogeneous_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_table_homogeneous_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_table_homogeneous_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_table_align_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_table_align_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_table_align_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_table_align_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_table_padding_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_table_padding_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_table_padding_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_table_padding_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_table_mirrored_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_table_mirrored_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_table_mirrored_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_table_mirrored_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_table_col_row_size_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_table_col_row_size_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_table_children_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_table_children_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_table_child_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_table_child_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_table_clear_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_table_clear);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_table_accessor_new_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_table_accessor_new);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_table_iterator_new_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_table_iterator_new);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_table_add_to_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_table_add_to);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_table_pack_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_table_pack_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_table_pack_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_table_pack);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_table_unpack_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_table_unpack);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< evas::table >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::table, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< evas::table >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::table, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< evas::table>
{
   template <typename U>
   struct type
   {
      operator evas::table() const
      {
         return evas::table(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void add()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_add());
      }

      void del()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_del());
      }

      void calculate()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_calculate());
      }

      void resize(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
      }

      Evas_Object_Table_Homogeneous_Mode homogeneous_get()
      {
         Evas_Object_Table_Homogeneous_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_homogeneous_get());
            return _tmp_ret;
      }

      void homogeneous_set(Evas_Object_Table_Homogeneous_Mode homogeneous_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_homogeneous_set(homogeneous_));
      }

      void align_get(double* horizontal_, double* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_align_get(horizontal_, vertical_));
      }

      void align_set(double horizontal_, double vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_align_set(horizontal_, vertical_));
      }

      void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_padding_get(horizontal_, vertical_));
      }

      void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_padding_set(horizontal_, vertical_));
      }

      bool mirrored_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_mirrored_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void mirrored_set(bool mirrored_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_mirrored_set(efl::eolian::to_c(mirrored_)));
      }

      void col_row_size_get(int* cols_, int* rows_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_col_row_size_get(cols_, rows_));
      }

      efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

      evas::object child_get(unsigned short col_, unsigned short row_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_child_get(col_, row_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void clear(bool clear_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_table_clear(efl::eolian::to_c(clear_)));
      }

      Eina_Accessor * accessor_new()
      {
         Eina_Accessor * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_accessor_new());
            return _tmp_ret;
      }

      Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_iterator_new());
            return _tmp_ret;
      }

      evas::object add_to()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_add_to());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool pack_get(evas::object child_, unsigned short* col_, unsigned short* row_, unsigned short* colspan_, unsigned short* rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_pack_get(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool pack(evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_pack(efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool unpack(evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_table_unpack(efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};

inline Eo_Class const* get_eo_class(tag<evas::table>)
{
   return (EVAS_TABLE_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TABLE_HH

